import { IgrStrategyBasedIndicator } from "./igr-strategy-based-indicator";
import { AverageTrueRangeIndicator } from "./AverageTrueRangeIndicator";
/**
 * Represents a IgxDataChartComponent Average True Range indicator series.
 * Default required members: High, Low, Close
*
* You can use the `IgrAverageTrueRangeIndicator` to measures a security's degree of price movement or volatility within a given period of time.
*
* ```ts
* <IgrDataChart
*     dataSource={this.state.dataSource}
*     width="700px"
*     height="500px">
*
*     <IgrCategoryXAxis name="xAxis" label="Year" />
*     <IgrNumericYAxis  name="yAxis" />
*
*     <IgrAverageTrueRangeIndicator
*         name="series1"
*         xAxisName="xAxis"
*         yAxisName="yAxis"
* 		openMemberPath="Open"
* 		volumeMemberPath="Volume"
*         highMemberPath="High"
*         lowMemberPath="Low" />
*  </IgrDataChart>
* ```
*
* ```ts
* let series = new IgrAverageTrueRangeIndicator({name:"series3"});
* series.xAxisName = this.xAxis;
* series.yAxisName = this.yAxis;
* series.openMemberPath = "open";
* series.highMemberPath = "high";
* series.lowMemberPath = "low";
* series.closeMemberPath = "close";
* this.chart.series.add(series);
* ```
*/
export class IgrAverageTrueRangeIndicator extends IgrStrategyBasedIndicator {
    createImplementation() {
        return new AverageTrueRangeIndicator();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
    }
    /**
     * Gets or sets the moving average period for the current AverageTrueRangeSeries object.
     * The typical, and initial, value for AverageTrueRange periods is 14.
    *
    * You can use the `period` to set the moving average.
    *
    * ```ts
    * <IgrDataChart
    *     dataSource={this.state.dataSource}
    *     width="700px"
    *     height="500px">
    *
    *     <IgrCategoryXAxis name="xAxis" label="Year" />
    *     <IgrNumericYAxis  name="yAxis" />
    *
    *     <IgrAverageTrueRangeIndicator
    *         name="series1"
    *         xAxisName="xAxis"
    *         yAxisName="yAxis"
    * 		openMemberPath="Open"
    * 		volumeMemberPath="Volume"
    *         highMemberPath="High"
    *         lowMemberPath="Low"
    * 		period="14" />
    *  </IgrDataChart>
    * ```
    *
    * ```ts
    * this.series.period = 14;
    * ```
    */
    get period() {
        return this.i.u6;
    }
    set period(v) {
        this.i.u6 = +v;
    }
}
