import { IgrAxis } from "./igr-axis";
import { DataToolTipLayerGroupingMode_$type } from "igniteui-react-core";
import { DataTooltipGroupedPositionX_$type } from "igniteui-react-core";
import { DataTooltipGroupedPositionY_$type } from "igniteui-react-core";
import { DataAbbreviationMode_$type } from "igniteui-react-core";
import { DataLegendValueMode_$type } from "igniteui-react-core";
import { DataLegendHeaderDateMode_$type } from "igniteui-react-core";
import { DataLegendHeaderTimeMode_$type } from "igniteui-react-core";
import { DataLegendSummaryType_$type } from "igniteui-react-core";
import { LegendItemBadgeShape_$type } from "igniteui-react-core";
import { DataLegendUnitsMode_$type } from "igniteui-react-core";
import { DataLegendLabelMode_$type } from "igniteui-react-core";
import { IgrAnnotationLayer } from "./igr-annotation-layer";
import { DataToolTipLayer } from "./DataToolTipLayer";
import { ensureBool, ensureEnum, brushToString, stringToBrush, arrayFindByName } from "igniteui-react-core";
import { Thickness } from "igniteui-react-core";
import { FontInfo } from "igniteui-react-core";
/**
 * Represents an annotation layer that displays grouped tooltips with summaries for series.
 * THIS IS A COMMUNITY TECHNOLOGY PREVIEW, not for use in production.
*/
export class IgrDataToolTipLayer extends IgrAnnotationLayer {
    createImplementation() {
        return new DataToolTipLayer();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
    }
    /**
     * Gets whether the series is an annotation layer displayed only when hovering over the chart.
    */
    get isAnnotationHoverLayer() {
        return this.i.db;
    }
    /**
     * Gets whether the default tooltip behaviors for the chart are disabled if this layer is present.
    */
    get isDefaultTooltipBehaviorDisabled() {
        return this.i.dl;
    }
    /**
     * Gets or sets the Axis to target this annotation to. If null, this annotation layer will not render content.
    */
    get targetAxis() {
        const r = this.i.rl;
        if (r == null) {
            return null;
        }
        if (!r.externalObject) {
            let e = IgrAxis._createFromInternal(r);
            if (e) {
                e._implementation = r;
            }
            r.externalObject = e;
        }
        return r.externalObject;
    }
    set targetAxis(v) {
        if (v != null && this._stylingContainer && v._styling)
            v._styling(this._stylingContainer, this, this);
        v == null ? this.i.rl = null : this.i.rl = v.i;
    }
    /**
     * Gets or sets whether to use value interpolation when drawing the tooltips.
    */
    get useInterpolation() {
        return this.i.sz;
    }
    set useInterpolation(v) {
        this.i.sz = ensureBool(v);
    }
    /**
     * Gets or sets the grouping mode to apply to use for the tooltip layer.
    */
    get groupingMode() {
        return this.i.r3;
    }
    set groupingMode(v) {
        this.i.r3 = ensureEnum(DataToolTipLayerGroupingMode_$type, v);
    }
    /**
     * Gets the actual resolved tooltip layer grouping mode.
    */
    get actualGroupingMode() {
        return this.i.r2;
    }
    set actualGroupingMode(v) {
        this.i.r2 = ensureEnum(DataToolTipLayerGroupingMode_$type, v);
    }
    /**
     * Gets or sets the offset of the tooltip layer on the X axis.
    */
    get positionOffsetX() {
        return this.i.s8;
    }
    set positionOffsetX(v) {
        this.i.s8 = +v;
    }
    /**
     * Gets or sets the offset of the tooltip layer on the Y axis.
    */
    get positionOffsetY() {
        return this.i.s9;
    }
    set positionOffsetY(v) {
        this.i.s9 = +v;
    }
    /**
     * Gets or sets the default offset of the tooltip layer on the X axis.
    */
    get defaultPositionOffsetX() {
        return this.i.s6;
    }
    set defaultPositionOffsetX(v) {
        this.i.s6 = +v;
    }
    /**
     * Gets or sets the default offset of the tooltip layer on the Y axis.
    */
    get defaultPositionOffsetY() {
        return this.i.s7;
    }
    set defaultPositionOffsetY(v) {
        this.i.s7 = +v;
    }
    /**
     * Gets or sets the tooltip position mode on the X axis for grouped series.
    */
    get groupedPositionModeX() {
        return this.i.rv;
    }
    set groupedPositionModeX(v) {
        this.i.rv = ensureEnum(DataTooltipGroupedPositionX_$type, v);
    }
    /**
     * Gets the actual resolved tooltip position mode on the X axis for grouped series.
    */
    get actualGroupedPositionModeX() {
        return this.i.ru;
    }
    set actualGroupedPositionModeX(v) {
        this.i.ru = ensureEnum(DataTooltipGroupedPositionX_$type, v);
    }
    /**
     * Gets or sets the tooltip position mode on the Y axis for grouped series.
    */
    get groupedPositionModeY() {
        return this.i.rz;
    }
    set groupedPositionModeY(v) {
        this.i.rz = ensureEnum(DataTooltipGroupedPositionY_$type, v);
    }
    /**
     * Gets the actual resolved tooltip position mode on the Y axis for grouped series.
    */
    get actualGroupedPositionModeY() {
        return this.i.ry;
    }
    set actualGroupedPositionModeY(v) {
        this.i.ry = ensureEnum(DataTooltipGroupedPositionY_$type, v);
    }
    /**
     * Gets or sets whether the data legend should update when the series data is mutated.
    */
    get shouldUpdateWhenSeriesDataChanges() {
        return this.i.sy;
    }
    set shouldUpdateWhenSeriesDataChanges(v) {
        this.i.sy = ensureBool(v);
    }
    /**
     * Gets or sets indexes or names of series to include in displaying in the data legend, e.g. "0, 1"
    */
    get includedSeries() {
        return this.i.ri;
    }
    set includedSeries(v) {
        if (v && !Array.isArray(v) && typeof (v) == "string") {
            const re = /\s*(?:,|\s|$)\s*/gm;
            v = v.split(re);
        }
        this.i.ri = v;
    }
    /**
     * Gets or sets indexes or names of series to exclude from displaying in the data legend, e.g. "0, 1"
     * The ExcludedSeries property takes precedences over values of IncludedSeries property
    */
    get excludedSeries() {
        return this.i.rd;
    }
    set excludedSeries(v) {
        if (v && !Array.isArray(v) && typeof (v) == "string") {
            const re = /\s*(?:,|\s|$)\s*/gm;
            v = v.split(re);
        }
        this.i.rd = v;
    }
    /**
     * Gets or sets names of data columns or their labels to include in displaying in the data legend, e.g. "High, Low" or "H, L"
     * The ExcludedColumns property takes precedences over values of IncludedColumns property
    */
    get includedColumns() {
        return this.i.rh;
    }
    set includedColumns(v) {
        if (v && !Array.isArray(v) && typeof (v) == "string") {
            const re = /\s*(?:,|\s|$)\s*/gm;
            v = v.split(re);
        }
        this.i.rh = v;
    }
    /**
     * Gets or sets names of data columns or their labels to exclude from displaying in the data legend, e.g. "High, Low" or "H, L"
     * The ExcludedColumns property takes precedences over values of IncludedColumns property
    */
    get excludedColumns() {
        return this.i.rc;
    }
    set excludedColumns(v) {
        if (v && !Array.isArray(v) && typeof (v) == "string") {
            const re = /\s*(?:,|\s|$)\s*/gm;
            v = v.split(re);
        }
        this.i.rc = v;
    }
    /**
     * Gets or sets mode for abbreviating large numbers displayed in the legend
     * This property is ignored when setting ValueFormatSpecifiers or ValueFormatString properties
    */
    get valueFormatAbbreviation() {
        return this.i.rm;
    }
    set valueFormatAbbreviation(v) {
        this.i.rm = ensureEnum(DataAbbreviationMode_$type, v);
    }
    /**
     * Gets or sets maximum digits for formating numbers displayed in the legend
     * This property is ignored when setting ValueFormatSpecifiers or ValueFormatString properties
    */
    get valueFormatMaxFractions() {
        return this.i.t8;
    }
    set valueFormatMaxFractions(v) {
        this.i.t8 = +v;
    }
    /**
     * Gets or sets minimum digits for formating numbers displayed in the legend
     * This property is ignored when setting ValueFormatSpecifiers or ValueFormatString properties
    */
    get valueFormatMinFractions() {
        return this.i.t9;
    }
    set valueFormatMinFractions(v) {
        this.i.t9 = +v;
    }
    /**
     * Gets or sets the mode for displaying values in the data legend, e.g. Currency ($500.25), Decimal (500.25), Integer (500)
    */
    get valueFormatMode() {
        return this.i.rs;
    }
    set valueFormatMode(v) {
        this.i.rs = ensureEnum(DataLegendValueMode_$type, v);
    }
    /**
     * Gets or sets globalization culture when displaying values as currencies, e.g. use "en-GB" to display British pound symbol when the ValueFormatMode property is set to 'Currency' mode
     * This property is ignored when setting ValueFormatSpecifiers or ValueFormatString properties
    */
    get valueFormatCulture() {
        return this.i.v3;
    }
    set valueFormatCulture(v) {
        this.i.v3 = v;
    }
    /**
     * Gets or sets whether or not use grouping separator, e.g, 15,000 for 15000
     * This property is ignored when setting ValueFormatSpecifiers or ValueFormatString properties
    */
    get valueFormatUseGrouping() {
        return this.i.s0;
    }
    set valueFormatUseGrouping(v) {
        this.i.s0 = ensureBool(v);
    }
    /**
     * Gets or sets the format string for values displayed in the data legend.
    */
    get valueFormatString() {
        return this.i.v9;
    }
    set valueFormatString(v) {
        this.i.v9 = v;
    }
    /**
     * Gets or sets the format specifiers to use with the ValueFormatString string.
    */
    get valueFormatSpecifiers() {
        return this.i.rj;
    }
    set valueFormatSpecifiers(v) {
        if (v && !Array.isArray(v) && typeof (v) == "string") {
            const re = /\s*(?:,|\s|$)\s*/gm;
            v = v.split(re);
        }
        this.i.rj = v;
    }
    get valueRowMarginBottom() {
        return this.i.y0 ? this.i.y0.bottom : NaN;
    }
    set valueRowMarginBottom(v) {
        this.ensureValueRowMargin();
        this.i.y0.bottom = +v;
        this.i.y0 = this.i.y0;
    }
    get valueRowMarginLeft() {
        return this.i.y0 ? this.i.y0.left : NaN;
    }
    set valueRowMarginLeft(v) {
        this.ensureValueRowMargin();
        this.i.y0.left = +v;
        this.i.y0 = this.i.y0;
    }
    get valueRowMarginRight() {
        return this.i.y0 ? this.i.y0.right : NaN;
    }
    set valueRowMarginRight(v) {
        this.ensureValueRowMargin();
        this.i.y0.right = +v;
        this.i.y0 = this.i.y0;
    }
    get valueRowMarginTop() {
        return this.i.y0 ? this.i.y0.top : NaN;
    }
    set valueRowMarginTop(v) {
        this.ensureValueRowMargin();
        this.i.y0.top = +v;
        this.i.y0 = this.i.y0;
    }
    ensureValueRowMargin() {
        if (this.i.y0) {
            return;
        }
        this.i.y0 = new Thickness(2);
    }
    /**
     * Gets or sets whether to show series rows.
    */
    get valueRowVisible() {
        return this.i.s1;
    }
    set valueRowVisible(v) {
        this.i.s1 = ensureBool(v);
    }
    /**
     * Gets or sets text displayed when data column is missing a value, e.g. "no data"
    */
    get valueTextWhenMissingData() {
        return this.i.wi;
    }
    set valueTextWhenMissingData(v) {
        this.i.wi = v;
    }
    /**
     * Gets or sets whether to use series colors when displaying values in the legend
    */
    get valueTextUseSeriesColors() {
        return this.i.s2;
    }
    set valueTextUseSeriesColors(v) {
        this.i.s2 = ensureBool(v);
    }
    get valueTextMarginBottom() {
        return this.i.y1 ? this.i.y1.bottom : NaN;
    }
    set valueTextMarginBottom(v) {
        this.ensureValueTextMargin();
        this.i.y1.bottom = +v;
        this.i.y1 = this.i.y1;
    }
    get valueTextMarginLeft() {
        return this.i.y1 ? this.i.y1.left : NaN;
    }
    set valueTextMarginLeft(v) {
        this.ensureValueTextMargin();
        this.i.y1.left = +v;
        this.i.y1 = this.i.y1;
    }
    get valueTextMarginRight() {
        return this.i.y1 ? this.i.y1.right : NaN;
    }
    set valueTextMarginRight(v) {
        this.ensureValueTextMargin();
        this.i.y1.right = +v;
        this.i.y1 = this.i.y1;
    }
    get valueTextMarginTop() {
        return this.i.y1 ? this.i.y1.top : NaN;
    }
    set valueTextMarginTop(v) {
        this.ensureValueTextMargin();
        this.i.y1.top = +v;
        this.i.y1 = this.i.y1;
    }
    ensureValueTextMargin() {
        if (this.i.y1) {
            return;
        }
        this.i.y1 = new Thickness(2);
    }
    /**
     * Gets or sets the units text color.
    */
    get valueTextColor() {
        return brushToString(this.i.yl);
    }
    set valueTextColor(v) {
        this.i.yl = stringToBrush(v);
    }
    /**
     * Gets or Sets the style to use for the units text.
    */
    get valueTextStyle() {
        if (this.i.sp == null) {
            return null;
        }
        return this.i.sp.fontString;
    }
    set valueTextStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.sp = fi;
    }
    /**
     * Gets or sets the format string for header text displayed in the data legend.
    */
    get headerFormatString() {
        return this.i.ur;
    }
    set headerFormatString(v) {
        this.i.ur = v;
    }
    /**
     * Gets or sets the format specifiers to use with the HeaderFormatString string.
    */
    get headerFormatSpecifiers() {
        return this.i.rg;
    }
    set headerFormatSpecifiers(v) {
        if (v && !Array.isArray(v) && typeof (v) == "string") {
            const re = /\s*(?:,|\s|$)\s*/gm;
            v = v.split(re);
        }
        this.i.rg = v;
    }
    /**
     * Gets or sets globalization culture when displaying header as date time
     * This property is ignored when setting HeaderFormatSpecifiers or HeaderFormatString properties
    */
    get headerFormatCulture() {
        return this.i.un;
    }
    set headerFormatCulture(v) {
        this.i.un = v;
    }
    /**
     * Gets or sets date format for the header
     * This property is ignored when setting HeaderFormatSpecifiers or HeaderFormatString properties
    */
    get headerFormatDate() {
        return this.i.rn;
    }
    set headerFormatDate(v) {
        this.i.rn = ensureEnum(DataLegendHeaderDateMode_$type, v);
    }
    /**
     * Gets or sets time format for the header
     * This property is ignored when setting HeaderFormatSpecifiers or HeaderFormatString properties
    */
    get headerFormatTime() {
        return this.i.ro;
    }
    set headerFormatTime(v) {
        this.i.ro = ensureEnum(DataLegendHeaderTimeMode_$type, v);
    }
    /**
     * Gets or sets the HeaderText for the data legend.
    */
    get headerText() {
        return this.i.uw;
    }
    set headerText(v) {
        this.i.uw = v;
    }
    /**
     * Gets or sets the header text color.
    */
    get headerTextColor() {
        return brushToString(this.i.yd);
    }
    set headerTextColor(v) {
        this.i.yd = stringToBrush(v);
    }
    get headerTextMarginBottom() {
        return this.i.yu ? this.i.yu.bottom : NaN;
    }
    set headerTextMarginBottom(v) {
        this.ensureHeaderTextMargin();
        this.i.yu.bottom = +v;
        this.i.yu = this.i.yu;
    }
    get headerTextMarginLeft() {
        return this.i.yu ? this.i.yu.left : NaN;
    }
    set headerTextMarginLeft(v) {
        this.ensureHeaderTextMargin();
        this.i.yu.left = +v;
        this.i.yu = this.i.yu;
    }
    get headerTextMarginRight() {
        return this.i.yu ? this.i.yu.right : NaN;
    }
    set headerTextMarginRight(v) {
        this.ensureHeaderTextMargin();
        this.i.yu.right = +v;
        this.i.yu = this.i.yu;
    }
    get headerTextMarginTop() {
        return this.i.yu ? this.i.yu.top : NaN;
    }
    set headerTextMarginTop(v) {
        this.ensureHeaderTextMargin();
        this.i.yu.top = +v;
        this.i.yu = this.i.yu;
    }
    ensureHeaderTextMargin() {
        if (this.i.yu) {
            return;
        }
        this.i.yu = new Thickness(2);
    }
    get headerRowMarginBottom() {
        return this.i.yt ? this.i.yt.bottom : NaN;
    }
    set headerRowMarginBottom(v) {
        this.ensureHeaderRowMargin();
        this.i.yt.bottom = +v;
        this.i.yt = this.i.yt;
    }
    get headerRowMarginLeft() {
        return this.i.yt ? this.i.yt.left : NaN;
    }
    set headerRowMarginLeft(v) {
        this.ensureHeaderRowMargin();
        this.i.yt.left = +v;
        this.i.yt = this.i.yt;
    }
    get headerRowMarginRight() {
        return this.i.yt ? this.i.yt.right : NaN;
    }
    set headerRowMarginRight(v) {
        this.ensureHeaderRowMargin();
        this.i.yt.right = +v;
        this.i.yt = this.i.yt;
    }
    get headerRowMarginTop() {
        return this.i.yt ? this.i.yt.top : NaN;
    }
    set headerRowMarginTop(v) {
        this.ensureHeaderRowMargin();
        this.i.yt.top = +v;
        this.i.yt = this.i.yt;
    }
    ensureHeaderRowMargin() {
        if (this.i.yt) {
            return;
        }
        this.i.yt = new Thickness(2);
    }
    /**
     * Gets or sets whether to show Header row.
    */
    get headerRowVisible() {
        return this.i.sr;
    }
    set headerRowVisible(v) {
        this.i.sr = ensureBool(v);
    }
    /**
     * Gets or Sets the style to use for the header text.
    */
    get headerTextStyle() {
        if (this.i.sh == null) {
            return null;
        }
        return this.i.sh.fontString;
    }
    set headerTextStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.sh = fi;
    }
    /**
     * Gets or sets the summary text color.
    */
    get summaryTitleTextColor() {
        return brushToString(this.i.yg);
    }
    set summaryTitleTextColor(v) {
        this.i.yg = stringToBrush(v);
    }
    /**
     * Gets or Sets the style to use for the summary text.
    */
    get summaryTitleTextStyle() {
        if (this.i.sk == null) {
            return null;
        }
        return this.i.sk.fontString;
    }
    set summaryTitleTextStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.sk = fi;
    }
    /**
     * Gets or sets the SummaryType for the data legend.
    */
    get summaryType() {
        return this.i.rq;
    }
    set summaryType(v) {
        this.i.rq = ensureEnum(DataLegendSummaryType_$type, v);
    }
    /**
     * Gets or sets the SummaryTitleText for the data legend.
    */
    get summaryTitleText() {
        return this.i.vf;
    }
    set summaryTitleText(v) {
        this.i.vf = v;
    }
    get summaryTitleTextMarginBottom() {
        return this.i.yx ? this.i.yx.bottom : NaN;
    }
    set summaryTitleTextMarginBottom(v) {
        this.ensureSummaryTitleTextMargin();
        this.i.yx.bottom = +v;
        this.i.yx = this.i.yx;
    }
    get summaryTitleTextMarginLeft() {
        return this.i.yx ? this.i.yx.left : NaN;
    }
    set summaryTitleTextMarginLeft(v) {
        this.ensureSummaryTitleTextMargin();
        this.i.yx.left = +v;
        this.i.yx = this.i.yx;
    }
    get summaryTitleTextMarginRight() {
        return this.i.yx ? this.i.yx.right : NaN;
    }
    set summaryTitleTextMarginRight(v) {
        this.ensureSummaryTitleTextMargin();
        this.i.yx.right = +v;
        this.i.yx = this.i.yx;
    }
    get summaryTitleTextMarginTop() {
        return this.i.yx ? this.i.yx.top : NaN;
    }
    set summaryTitleTextMarginTop(v) {
        this.ensureSummaryTitleTextMargin();
        this.i.yx.top = +v;
        this.i.yx = this.i.yx;
    }
    ensureSummaryTitleTextMargin() {
        if (this.i.yx) {
            return;
        }
        this.i.yx = new Thickness(2);
    }
    get summaryRowMarginBottom() {
        return this.i.yw ? this.i.yw.bottom : NaN;
    }
    set summaryRowMarginBottom(v) {
        this.ensureSummaryRowMargin();
        this.i.yw.bottom = +v;
        this.i.yw = this.i.yw;
    }
    get summaryRowMarginLeft() {
        return this.i.yw ? this.i.yw.left : NaN;
    }
    set summaryRowMarginLeft(v) {
        this.ensureSummaryRowMargin();
        this.i.yw.left = +v;
        this.i.yw = this.i.yw;
    }
    get summaryRowMarginRight() {
        return this.i.yw ? this.i.yw.right : NaN;
    }
    set summaryRowMarginRight(v) {
        this.ensureSummaryRowMargin();
        this.i.yw.right = +v;
        this.i.yw = this.i.yw;
    }
    get summaryRowMarginTop() {
        return this.i.yw ? this.i.yw.top : NaN;
    }
    set summaryRowMarginTop(v) {
        this.ensureSummaryRowMargin();
        this.i.yw.top = +v;
        this.i.yw = this.i.yw;
    }
    ensureSummaryRowMargin() {
        if (this.i.yw) {
            return;
        }
        this.i.yw = new Thickness(2);
    }
    /**
     * Gets or sets the units text color.
    */
    get summaryValueTextColor() {
        return brushToString(this.i.yi);
    }
    set summaryValueTextColor(v) {
        this.i.yi = stringToBrush(v);
    }
    /**
     * Gets or Sets the style to use for the units text.
    */
    get summaryValueTextStyle() {
        if (this.i.sm == null) {
            return null;
        }
        return this.i.sm.fontString;
    }
    set summaryValueTextStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.sm = fi;
    }
    /**
     * Gets or sets the units text for the data legend.
    */
    get summaryLabelText() {
        return this.i.va;
    }
    set summaryLabelText(v) {
        this.i.va = v;
    }
    /**
     * Gets or sets the units text color.
    */
    get summaryLabelTextColor() {
        return brushToString(this.i.yf);
    }
    set summaryLabelTextColor(v) {
        this.i.yf = stringToBrush(v);
    }
    /**
     * Gets or Sets the style to use for the units text.
    */
    get summaryLabelTextStyle() {
        if (this.i.sj == null) {
            return null;
        }
        return this.i.sj.fontString;
    }
    set summaryLabelTextStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.sj = fi;
    }
    /**
     * Gets or sets the units text for the data legend.
    */
    get summaryUnitsText() {
        return this.i.vl;
    }
    set summaryUnitsText(v) {
        this.i.vl = v;
    }
    /**
     * Gets or sets the units text color.
    */
    get summaryUnitsTextColor() {
        return brushToString(this.i.yh);
    }
    set summaryUnitsTextColor(v) {
        this.i.yh = stringToBrush(v);
    }
    /**
     * Gets or Sets the style to use for the units text.
    */
    get summaryUnitsTextStyle() {
        if (this.i.sl == null) {
            return null;
        }
        return this.i.sl.fontString;
    }
    set summaryUnitsTextStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.sl = fi;
    }
    get badgeMarginBottom() {
        return this.i.ys ? this.i.ys.bottom : NaN;
    }
    set badgeMarginBottom(v) {
        this.ensureBadgeMargin();
        this.i.ys.bottom = +v;
        this.i.ys = this.i.ys;
    }
    get badgeMarginLeft() {
        return this.i.ys ? this.i.ys.left : NaN;
    }
    set badgeMarginLeft(v) {
        this.ensureBadgeMargin();
        this.i.ys.left = +v;
        this.i.ys = this.i.ys;
    }
    get badgeMarginRight() {
        return this.i.ys ? this.i.ys.right : NaN;
    }
    set badgeMarginRight(v) {
        this.ensureBadgeMargin();
        this.i.ys.right = +v;
        this.i.ys = this.i.ys;
    }
    get badgeMarginTop() {
        return this.i.ys ? this.i.ys.top : NaN;
    }
    set badgeMarginTop(v) {
        this.ensureBadgeMargin();
        this.i.ys.top = +v;
        this.i.ys = this.i.ys;
    }
    ensureBadgeMargin() {
        if (this.i.ys) {
            return;
        }
        this.i.ys = new Thickness(2);
    }
    /**
     * Gets or sets the BadgeShape for the data legend.
    */
    get badgeShape() {
        return this.i.r7;
    }
    set badgeShape(v) {
        this.i.r7 = ensureEnum(LegendItemBadgeShape_$type, v);
    }
    /**
     * Gets or sets the UnitsMode for the data legend.
    */
    get unitsDisplayMode() {
        return this.i.rr;
    }
    set unitsDisplayMode(v) {
        this.i.rr = ensureEnum(DataLegendUnitsMode_$type, v);
    }
    /**
     * Gets or sets the units text for the data legend.
    */
    get unitsText() {
        return this.i.vw;
    }
    set unitsText(v) {
        this.i.vw = v;
    }
    /**
     * Gets or sets the units text color.
    */
    get unitsTextColor() {
        return brushToString(this.i.yk);
    }
    set unitsTextColor(v) {
        this.i.yk = stringToBrush(v);
    }
    get unitsTextMarginBottom() {
        return this.i.yz ? this.i.yz.bottom : NaN;
    }
    set unitsTextMarginBottom(v) {
        this.ensureUnitsTextMargin();
        this.i.yz.bottom = +v;
        this.i.yz = this.i.yz;
    }
    get unitsTextMarginLeft() {
        return this.i.yz ? this.i.yz.left : NaN;
    }
    set unitsTextMarginLeft(v) {
        this.ensureUnitsTextMargin();
        this.i.yz.left = +v;
        this.i.yz = this.i.yz;
    }
    get unitsTextMarginRight() {
        return this.i.yz ? this.i.yz.right : NaN;
    }
    set unitsTextMarginRight(v) {
        this.ensureUnitsTextMargin();
        this.i.yz.right = +v;
        this.i.yz = this.i.yz;
    }
    get unitsTextMarginTop() {
        return this.i.yz ? this.i.yz.top : NaN;
    }
    set unitsTextMarginTop(v) {
        this.ensureUnitsTextMargin();
        this.i.yz.top = +v;
        this.i.yz = this.i.yz;
    }
    ensureUnitsTextMargin() {
        if (this.i.yz) {
            return;
        }
        this.i.yz = new Thickness(2);
    }
    /**
     * Gets or Sets the style to use for the units text.
    */
    get unitsTextStyle() {
        if (this.i.so == null) {
            return null;
        }
        return this.i.so.fontString;
    }
    set unitsTextStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.so = fi;
    }
    get titleTextMarginBottom() {
        return this.i.yy ? this.i.yy.bottom : NaN;
    }
    set titleTextMarginBottom(v) {
        this.ensureTitleTextMargin();
        this.i.yy.bottom = +v;
        this.i.yy = this.i.yy;
    }
    get titleTextMarginLeft() {
        return this.i.yy ? this.i.yy.left : NaN;
    }
    set titleTextMarginLeft(v) {
        this.ensureTitleTextMargin();
        this.i.yy.left = +v;
        this.i.yy = this.i.yy;
    }
    get titleTextMarginRight() {
        return this.i.yy ? this.i.yy.right : NaN;
    }
    set titleTextMarginRight(v) {
        this.ensureTitleTextMargin();
        this.i.yy.right = +v;
        this.i.yy = this.i.yy;
    }
    get titleTextMarginTop() {
        return this.i.yy ? this.i.yy.top : NaN;
    }
    set titleTextMarginTop(v) {
        this.ensureTitleTextMargin();
        this.i.yy.top = +v;
        this.i.yy = this.i.yy;
    }
    ensureTitleTextMargin() {
        if (this.i.yy) {
            return;
        }
        this.i.yy = new Thickness(2);
    }
    /**
     * Gets or sets the display text color.
    */
    get titleTextColor() {
        return brushToString(this.i.yj);
    }
    set titleTextColor(v) {
        this.i.yj = stringToBrush(v);
    }
    /**
     * Gets or Sets the style to use for the display text.
    */
    get titleTextStyle() {
        if (this.i.sn == null) {
            return null;
        }
        return this.i.sn.fontString;
    }
    set titleTextStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.sn = fi;
    }
    /**
     * Gets or sets the mode for displaying labels before series values in the data legend, e.g. O: H: L: C: for financial series
    */
    get labelDisplayMode() {
        return this.i.rp;
    }
    set labelDisplayMode(v) {
        this.i.rp = ensureEnum(DataLegendLabelMode_$type, v);
    }
    /**
     * Gets or sets the units text color.
    */
    get labelTextColor() {
        return brushToString(this.i.ye);
    }
    set labelTextColor(v) {
        this.i.ye = stringToBrush(v);
    }
    get labelTextMarginBottom() {
        return this.i.yv ? this.i.yv.bottom : NaN;
    }
    set labelTextMarginBottom(v) {
        this.ensureLabelTextMargin();
        this.i.yv.bottom = +v;
        this.i.yv = this.i.yv;
    }
    get labelTextMarginLeft() {
        return this.i.yv ? this.i.yv.left : NaN;
    }
    set labelTextMarginLeft(v) {
        this.ensureLabelTextMargin();
        this.i.yv.left = +v;
        this.i.yv = this.i.yv;
    }
    get labelTextMarginRight() {
        return this.i.yv ? this.i.yv.right : NaN;
    }
    set labelTextMarginRight(v) {
        this.ensureLabelTextMargin();
        this.i.yv.right = +v;
        this.i.yv = this.i.yv;
    }
    get labelTextMarginTop() {
        return this.i.yv ? this.i.yv.top : NaN;
    }
    set labelTextMarginTop(v) {
        this.ensureLabelTextMargin();
        this.i.yv.top = +v;
        this.i.yv = this.i.yv;
    }
    ensureLabelTextMargin() {
        if (this.i.yv) {
            return;
        }
        this.i.yv = new Thickness(2);
    }
    /**
     * Gets or Sets the style to use for the units text.
    */
    get labelTextStyle() {
        if (this.i.si == null) {
            return null;
        }
        return this.i.si.fontString;
    }
    set labelTextStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.si = fi;
    }
    findByName(name) {
        var baseResult = super.findByName(name);
        if (baseResult) {
            return baseResult;
        }
        if (this.targetAxis && this.targetAxis.name && this.targetAxis.name == name) {
            return this.targetAxis;
        }
        if (this.valueFormatSpecifiers != null && arrayFindByName(this.valueFormatSpecifiers, name)) {
            return arrayFindByName(this.valueFormatSpecifiers, name);
        }
        if (this.headerFormatSpecifiers != null && arrayFindByName(this.headerFormatSpecifiers, name)) {
            return arrayFindByName(this.headerFormatSpecifiers, name);
        }
        return null;
    }
    _styling(container, component, parent) {
        super._styling(container, component, parent);
        this._inStyling = true;
        if (this.targetAxis && this.targetAxis._styling) {
            this.targetAxis._styling(container, component, this);
        }
        this._inStyling = false;
    }
    /**
     * Hides any tooltips presented by the layer, if any.
    
    */
    hideToolTips() {
        this.i.lg();
    }
    /**
     * Hides any tooltips presented by the layer, if any.
    
    */
    hideToolTipsImmediate() {
        this.i.lh();
    }
}
