import { IgrStrategyBasedIndicator } from "./igr-strategy-based-indicator";
import { OnBalanceVolumeIndicator } from "./OnBalanceVolumeIndicator";
/**
 * Represents a IgxDataChartComponent On Balance Bolume indicator series.
 * Default required members: Close, Volume
*
* You can use the `IgrOnBalanceVolumeIndicator` to calculate a running total of sales volume for a stock.
*
* ```ts
* <IgrDataChart
*     dataSource={this.state.dataSource}
*     width="700px"
*     height="500px">
*
*     <IgrCategoryXAxis name="xAxis" label="Year" />
*     <IgrNumericYAxis  name="yAxis" />
*
*     <IgrOnBalanceVolumeIndicator
*         name="series1"
*         xAxisName="xAxis"
*         yAxisName="yAxis"
* 		openMemberPath="Open"
* 		closeMemberPath="Close"
*         highMemberPath="High"
*         lowMemberPath="Low" />
*  </IgrDataChart>
* ```
*
* ```ts
* this.series = new IgrOnBalanceVolumeIndicator({ name: "series1" });
* this.series.dataSource = this.data;
* this.series.xAxis = this.categoryXAxis;
* this.series.yAxis = this.numericYAxis;
* this.series.xAxisName = "xAxis";
* this.series.yAxisName = "yAxis";
* this.series.openMemberPath = "open";
* this.series.highMemberPath = "high";
* this.series.lowMemberPath = "low";
* this.series.closeMemberPath = "close";
* ```
*/
export class IgrOnBalanceVolumeIndicator extends IgrStrategyBasedIndicator {
    createImplementation() {
        return new OnBalanceVolumeIndicator();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
    }
}
