import { IgrStrategyBasedIndicator } from "./igr-strategy-based-indicator";
import { PercentageVolumeOscillatorIndicator } from "./PercentageVolumeOscillatorIndicator";
/**
 * Represents a IgxDataChartComponent Percentage Volume Oscillator (PVO) series.
 * Default required members: Volume
*
* You can use the `IgrPercentageVolumeOscillatorIndicator` to show the percentage difference volume.
*
* ```ts
* <IgrDataChart
*     dataSource={this.state.dataSource}
*     width="700px"
*     height="500px">
*
*
*     <IgrCategoryXAxis name="xAxis" label="Date" />
*     <IgrNumericYAxis  name="yAxis" />
*
*    <IgrPercentageVolumeOscillatorIndicator
*     name="series1"
*     xAxisName="xAxis"
*     yAxisName="yAxis"
*     lowMemberPath="Low"
*     highMemberPath="High"
*     openMemberPath="Open"
*     closeMemberPath="Close" />
*  </IgrDataChart>
* ```
*
* ```ts
* let series = new IgrPercentageVolumeOscillatorIndicator({name:"series1"});
* series.xAxisName = this.xAxis;
* series.yAxisName = this.yAxis;
* series.xAxis = this.categoryXAxis;
* series.yAxis = this.numericYAxis;
* series.openMemberPath = "open";
* series.highMemberPath = "high";
* series.lowMemberPath = "low";
* series.closeMemberPath = "close";
* ```
*/
export class IgrPercentageVolumeOscillatorIndicator extends IgrStrategyBasedIndicator {
    createImplementation() {
        return new PercentageVolumeOscillatorIndicator();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
    }
    /**
     * Gets or sets the short moving average period for the current PercentageVolumeOscillatorIndicator object.
     * The typical, and initial, value for short PVO periods is 10.
    *
    * You can use the `shortPeriod` to set the short moving average period.
    *
    * ```ts
    * this.series.shortPeriod = 30;
    * ```
    *
    * ```ts
    * <IgrDataChart
    *     dataSource={this.state.dataSource}
    *     width="700px"
    *     height="500px">
    *
    *
    *     <IgrCategoryXAxis name="xAxis" label="Date" />
    *     <IgrNumericYAxis  name="yAxis" />
    *
    *    <IgrPercentageVolumeOscillatorIndicator
    *     name="series1"
    *     xAxisName="xAxis"
    *     yAxisName="yAxis"
    *     lowMemberPath="Low"
    *     highMemberPath="High"
    *     openMemberPath="Open"
    *     shortPeriod = {30} />
    *  </IgrDataChart>
    * ```
    */
    get shortPeriod() {
        return this.i.shortPeriod;
    }
    set shortPeriod(v) {
        this.i.shortPeriod = +v;
    }
    /**
     * Gets or sets the short moving average period for the current PercentageVolumeOscillatorIndicator object.
     * The typical, and initial, value for long PVO periods is 30.
    *
    * You can use the `longPeriod` to set the long moving average period.
    *
    * ```ts
    * this.series.longPeriod = 30;
    * ```
    *
    * ```ts
    * <IgrDataChart
    *     dataSource={this.state.dataSource}
    *     width="700px"
    *     height="500px">
    *
    *
    *     <IgrCategoryXAxis name="xAxis" label="Date" />
    *     <IgrNumericYAxis  name="yAxis" />
    *
    *    <IgrPercentageVolumeOscillatorIndicator
    *     name="series1"
    *     xAxisName="xAxis"
    *     yAxisName="yAxis"
    *     lowMemberPath="Low"
    *     highMemberPath="High"
    *     openMemberPath="Open"
    *     longPeriod = {30} />
    *  </IgrDataChart>
    * ```
    */
    get longPeriod() {
        return this.i.longPeriod;
    }
    set longPeriod(v) {
        this.i.longPeriod = +v;
    }
}
