import { __extends } from "tslib";
import { IgrStrategyBasedIndicator } from "./igr-strategy-based-indicator";
import { NegativeVolumeIndexIndicator } from "./NegativeVolumeIndexIndicator";
/**
 * Represents a IgxDataChartComponent Negative Volume Index indicator (NVI) series.
 * Default required members: Close, Volume
*
* The `IgrNegativeVolumeIndexIndicator` (NVI) is a finacial indicator frequently used in combination with the PositiveVolumeIndexIndicator. This calculation can be used to identify bull markets. These two indicators are based on the premise that smart money trades on low volume days and less informed or overly optimistic investors trade on high volume days.
*
* Using this indicator requires setting both the `CloseMemberPath` and `VolumeMemberPath`.
*
* ```ts
* <IgrDataChart
*     dataSource={this.state.dataSource}
*     width="700px"
*     height="500px">
*
*    <IgrOrdinalTimeXAxis name="xAxis" label="Date" />
*    <IgrNumericYAxis  name="yAxis" />
*
*     <IgrNegativeVolumeIndexIndicator
*         name="series1"
*         xAxisName="xAxis"
*         yAxisName="yAxis"
* 		volumeMemberPath="Volume"
*         closeMemberPath = "Close"/>
*  </IgrDataChart>
* ```
*
* ```ts
* let series = new IgrNegativeVolumeIndexIndicator({name:"series1"});
* series.xAxisName = this.xAxis;
* series.yAxisName = this.yAxis;
* series.volumeMemberPath= "volume" ;
* series.closeMemberPath = "close";
* ```
*/
var IgrNegativeVolumeIndexIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrNegativeVolumeIndexIndicator, _super);
    function IgrNegativeVolumeIndexIndicator(props) {
        return _super.call(this, props) || this;
    }
    IgrNegativeVolumeIndexIndicator.prototype.createImplementation = function () {
        return new NegativeVolumeIndexIndicator();
    };
    Object.defineProperty(IgrNegativeVolumeIndexIndicator.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    return IgrNegativeVolumeIndexIndicator;
}(IgrStrategyBasedIndicator));
export { IgrNegativeVolumeIndexIndicator };
