import { __extends } from "tslib";
import { IgrStrategyBasedIndicator } from "./igr-strategy-based-indicator";
import { TypicalPriceIndicator } from "./TypicalPriceIndicator";
/**
 * Represents a IgxDataChartComponent Typical Price indicator series.
 * The typical price indicator is represented as a arithmetic average
 * of the High, Low, and Close for a day.
 * Default required members: High, Low, Close
*
* The `IgrTypicalPriceIndicator` class represents a IgxDataChartComponent Typical Price indicator series.
*
* ```ts
*   <IgrDataChart
*     dataSource={this.state.dataSource}
*     width="700px"
*     height="500px">
* 		<IgrCategoryXAxis name="xAxis" label="Date" />
* 		<IgrNumericYAxis  name="yAxis" />
* <IgrTypicalPriceIndicator
*     name="series1"
*     xAxisName="xAxis"
*     yAxisName="yAxis"
*     lowMemberPath="Low"
*     highMemberPath="High"
*     openMemberPath="Open"
*     closeMemberPath="Close"
*     volumeMemberPath="Volume" />
*  </IgrDataChart>
* ```
*
* ```ts
* let series = new IgrTypicalPriceIndicator({name: "series"});
* series.xAxis = this.xAxis;
* series.yAxis = this.yAxis;
* series.openMemberPath = "open";
* series.highMemberPath = "high";
* series.lowMemberPath = "low";
* series.closeMemberPath = "close";
* this.chart.series.add(series);
* ```
*/
var IgrTypicalPriceIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrTypicalPriceIndicator, _super);
    function IgrTypicalPriceIndicator(props) {
        return _super.call(this, props) || this;
    }
    IgrTypicalPriceIndicator.prototype.createImplementation = function () {
        return new TypicalPriceIndicator();
    };
    Object.defineProperty(IgrTypicalPriceIndicator.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    return IgrTypicalPriceIndicator;
}(IgrStrategyBasedIndicator));
export { IgrTypicalPriceIndicator };
