import { IgPoint } from "igniteui-react-core";
import { TrendLineType } from "igniteui-react-core";
import { IgrRadialBase, IIgrRadialBaseProps } from "./igr-radial-base";
import { AnchoredRadialSeries } from "./AnchoredRadialSeries";
/**
 * Represents the base class for all IgxDataChartComponent anchored radial category series.
*/
export declare abstract class IgrAnchoredRadialSeries<P extends IIgrAnchoredRadialSeriesProps = IIgrAnchoredRadialSeriesProps> extends IgrRadialBase<P> {
    /**
                                 * @hidden
                                 */
    get i(): AnchoredRadialSeries;
    constructor(props: P);
    /**
     * Gets or sets the item path that provides the values for the current series.
    */
    get valueMemberPath(): string;
    set valueMemberPath(v: string);
    /**
     * Gets or sets the label displayed before series value in the Data Legend.
    */
    get valueMemberAsLegendLabel(): string;
    set valueMemberAsLegendLabel(v: string);
    /**
     * Gets or sets the unit displayed after series value in the Data Legend.
    */
    get valueMemberAsLegendUnit(): string;
    set valueMemberAsLegendUnit(v: string);
    /**
     * Gets or sets the trend type for the current series object.
    */
    get trendLineType(): TrendLineType;
    set trendLineType(v: TrendLineType);
    /**
     * Gets or sets the brush that specifies how to the current series
     * object's Trend line is drawn.
    */
    get trendLineBrush(): string;
    set trendLineBrush(v: string);
    /**
     * Gets the effective TrendLineBrush for this series.
    */
    get actualTrendLineBrush(): string;
    set actualTrendLineBrush(v: string);
    /**
     * Gets or sets the thickness of the current series object's trend line.
    */
    get trendLineThickness(): number;
    set trendLineThickness(v: number);
    /**
     * Gets or sets the trend line period for the current series.
     * The typical, and initial, value for bollinger band periods is 20.
    */
    get trendLinePeriod(): number;
    set trendLinePeriod(v: number);
    /**
     * Sets or Gets the Z index of the trendline.
    */
    get trendLineZIndex(): number;
    set trendLineZIndex(v: number);
    get hasValueAxis(): boolean;
    get isValueAxisInverted(): boolean;
    getItemValue(item: any, memberPathName: string): any;
    getPreviousOrExactIndex(world: IgPoint, skipUnknowns: boolean): number;
    getNextOrExactIndex(world: IgPoint, skipUnknowns: boolean): number;
    getSeriesValue(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): number;
    getSeriesValuePosition(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): IgPoint;
    /**
     * Returns the offset value for this series if grouped on a category axis.
    
    */
    getOffsetValue(): number;
    /**
     * Returns the width of the category grouping this series is in.
    
    */
    getCategoryWidth(): number;
    /**
     * Scrolls the specified item into the view.
    
    * @param item  * The item to scroll into view.
    */
    scrollIntoView(item: any): boolean;
}
export interface IIgrAnchoredRadialSeriesProps extends IIgrRadialBaseProps {
    /**
     * Gets or sets the item path that provides the values for the current series.
    */
    valueMemberPath?: string;
    /**
     * Gets or sets the label displayed before series value in the Data Legend.
    */
    valueMemberAsLegendLabel?: string;
    /**
     * Gets or sets the unit displayed after series value in the Data Legend.
    */
    valueMemberAsLegendUnit?: string;
    /**
     * Gets or sets the trend type for the current series object.
    */
    trendLineType?: TrendLineType | string;
    /**
     * Gets or sets the brush that specifies how to the current series
     * object's Trend line is drawn.
    */
    trendLineBrush?: string;
    /**
     * Gets the effective TrendLineBrush for this series.
    */
    actualTrendLineBrush?: string;
    /**
     * Gets or sets the thickness of the current series object's trend line.
    */
    trendLineThickness?: number | string;
    /**
     * Gets or sets the trend line period for the current series.
     * The typical, and initial, value for bollinger band periods is 20.
    */
    trendLinePeriod?: number | string;
    /**
     * Sets or Gets the Z index of the trendline.
    */
    trendLineZIndex?: number | string;
}
