import { IgPoint } from "igniteui-react-core";
import { IgrSeries, IIgrSeriesProps } from "./igr-series";
import { AnnotationLayer } from "./AnnotationLayer";
/**
 * Represents the base class for annotation layer types. Annotations will usually disable some of the default hover/touch behaviors of the chart when they are introduced to the series collection.
 * In return they provide some valuable information as the cursor is moved by hovering over the chart, or performing a press-hold-drag interaction in touch mode.
*/
export declare abstract class IgrAnnotationLayer<P extends IIgrAnnotationLayerProps = IIgrAnnotationLayerProps> extends IgrSeries<P> {
    /**
                                 * @hidden
                                 */
    get i(): AnnotationLayer;
    constructor(props: P);
    /**
     * Gets or sets whether this series should take up an index for auto brush coloring.
    */
    get useIndex(): boolean;
    set useIndex(v: boolean);
    /**
     * Gets or sets whether this series interacts with the chart legend.
    */
    get useLegend(): boolean;
    set useLegend(v: boolean);
    /**
     * Gets or sets the world position to use instead of the pointer position for this annotation layer. If you set this value, rather than responding to the pointer, this layer will be fixed on the provided world position.
     * A world position has x and y values that range from 0 to 1 that represent the global position of the cursor relative to the entire ranges of the axes. The default of (NaN, NaN) means that the layer should react to pointer movement.
    */
    get cursorPosition(): IgPoint;
    set cursorPosition(v: IgPoint);
    /**
     * Gets or sets whether the series viewer's default crosshair should be disabled by the presence of this layer.
    */
    get isDefaultCrosshairDisabled(): boolean;
    set isDefaultCrosshairDisabled(v: boolean);
    /**
     * Gets whether or not the default crosshair behavior is disabled.
    */
    get isDefaultCrosshairBehaviorDisabled(): boolean;
    /**
     * Gets if the series uses an index, which can be used to auto-assign it a color.
    */
    get isIndexed(): boolean;
    /**
     * Gets if the series should appear in any legends.
    */
    get isUsableInLegend(): boolean;
    /**
     * Gets whether this series is an annotation layer.
    */
    get isAnnotationLayer(): boolean;
    /**
     * Gets or sets whether this layer renders as an overlay or not.
    */
    get shouldRenderAsOverlay(): boolean;
    set shouldRenderAsOverlay(v: boolean);
}
export interface IIgrAnnotationLayerProps extends IIgrSeriesProps {
    /**
     * Gets or sets whether this series should take up an index for auto brush coloring.
    */
    useIndex?: boolean | string;
    /**
     * Gets or sets whether this series interacts with the chart legend.
    */
    useLegend?: boolean | string;
    /**
     * Gets or sets the world position to use instead of the pointer position for this annotation layer. If you set this value, rather than responding to the pointer, this layer will be fixed on the provided world position.
     * A world position has x and y values that range from 0 to 1 that represent the global position of the cursor relative to the entire ranges of the axes. The default of (NaN, NaN) means that the layer should react to pointer movement.
    */
    cursorPosition?: IgPoint | string;
    /**
     * Gets or sets whether the series viewer's default crosshair should be disabled by the presence of this layer.
    */
    isDefaultCrosshairDisabled?: boolean | string;
    /**
     * Gets or sets whether this layer renders as an overlay or not.
    */
    shouldRenderAsOverlay?: boolean | string;
}
