import { IgRect } from "igniteui-react-core";
import { IgPoint } from "igniteui-react-core";
import { IgrNumericXAxis } from "./igr-numeric-x-axis";
import { IgrCategoryYAxis } from "./igr-category-y-axis";
import { IgrColumnFragment, IIgrColumnFragmentProps } from "./igr-column-fragment";
import { BarFragment } from "./BarFragment";
/**
 * Represents one part of a StackedBarSeries.
*/
export declare class IgrBarFragment<P extends IIgrBarFragmentProps = IIgrBarFragmentProps> extends IgrColumnFragment<P> {
    protected createImplementation(): BarFragment;
    /**
                                 * @hidden
                                 */
    get i(): BarFragment;
    constructor(props: P);
    /**
     * Gets whether the current series shows a bar shape.
    */
    get isBar(): boolean;
    /**
     * Overridden by derived series classes to indicate when marker-less display is preferred or not.
    */
    get isMarkerlessDisplayPreferred(): boolean;
    /**
     * Gets whether the current series shows a column shape.
    */
    get isColumn(): boolean;
    /**
     * The X-Axis for this BarFragment.
    */
    get barFragmentXAxis(): IgrNumericXAxis;
    /**
     * The Y-Axis for this BarFragment.
    */
    get barFragmentYAxis(): IgrCategoryYAxis;
    get isVertical(): boolean;
    protected _styling(container: any, component: any, parent?: any): void;
    /**
     * Gets the precise item index, if possible, based on the closeness to the previous or next whole integer. If the series cannot provide this information, GetExactItemIndex will return the same integer value as GetItemIndex.
    
    * @param world  * The world position for which to return the index.
    */
    getExactItemIndex(world: IgPoint): number;
    /**
     * If possible, will return the best available value bounding box within the series that has the best value match for the world position provided.
    
    * @param world  * The world coordinate for which to get a value bounding box for
    */
    getSeriesValueBoundingBox(world: IgPoint): IgRect;
    /**
     * Gets the item that is the best match for the specified world coordinates.
    
    * @param world  * The world coordinates to use.
    */
    getItem(world: IgPoint): any;
}
export interface IIgrBarFragmentProps extends IIgrColumnFragmentProps {
}
