import { IgPoint } from "igniteui-react-core";
import { IgrNumericXAxis } from "./igr-numeric-x-axis";
import { IgrNumericYAxis } from "./igr-numeric-y-axis";
import { IgrProgressiveLoadStatusEventArgs } from "./igr-progressive-load-status-event-args";
import { IgrSeries, IIgrSeriesProps } from "./igr-series";
import { HighDensityScatterSeries } from "./HighDensityScatterSeries";
import { IgrAxis } from "./igr-axis";
/**
 * Represents a IgxDataChartComponent series where a high volume of scatter points can be displayed.
*/
export declare class IgrHighDensityScatterSeries extends IgrSeries<IIgrHighDensityScatterSeriesProps> {
    protected createImplementation(): HighDensityScatterSeries;
    /**
                                 * @hidden
                                 */
    get i(): HighDensityScatterSeries;
    constructor(props: IIgrHighDensityScatterSeriesProps);
    /**
     * Gets whether the current series shows pixels.
    */
    get isPixel(): boolean;
    /**
     * Checks if this series is a scatter series
    */
    get isScatter(): boolean;
    /**
     * Gets or sets the effective x-axis for the current object.
    */
    get xAxis(): IgrNumericXAxis;
    set xAxis(v: IgrNumericXAxis);
    private _xAxisName;
    /**
    * Gets or sets the name to use to resolve xAxis from markup.
    */
    get xAxisName(): string;
    set xAxisName(v: string);
    /**
     * Gets or sets the effective y-axis for the current object.
    */
    get yAxis(): IgrNumericYAxis;
    set yAxis(v: IgrNumericYAxis);
    private _yAxisName;
    /**
    * Gets or sets the name to use to resolve yAxis from markup.
    */
    get yAxisName(): string;
    set yAxisName(v: string);
    /**
     * Gets or sets the x value mapping property for the current series object.
    */
    get xMemberPath(): string;
    set xMemberPath(v: string);
    /**
     * Gets or sets the label displayed before series X value in the Data Legend.
    */
    get xMemberAsLegendLabel(): string;
    set xMemberAsLegendLabel(v: string);
    /**
     * Gets or sets the label displayed before series Y value in the Data Legend.
    */
    get yMemberAsLegendLabel(): string;
    set yMemberAsLegendLabel(v: string);
    /**
     * Gets or sets the unit after displayed after series X value in the Data Legend.
    */
    get xMemberAsLegendUnit(): string;
    set xMemberAsLegendUnit(v: string);
    /**
     * Gets or sets the unit after displayed after series Y value in the Data Legend.
    */
    get yMemberAsLegendUnit(): string;
    set yMemberAsLegendUnit(v: string);
    /**
     * Gets or sets the y value mapping property for the current series object.
    */
    get yMemberPath(): string;
    set yMemberPath(v: string);
    /**
     * Gets or sets the whether to use use brute force mode.
    */
    get useBruteForce(): boolean;
    set useBruteForce(v: boolean);
    /**
     * Gets or sets the whether to progressively load the data into the chart.
    */
    get progressiveLoad(): boolean;
    set progressiveLoad(v: boolean);
    /**
     * Gets or sets the density value that maps to the minimum heat color.
    */
    get heatMinimum(): number;
    set heatMinimum(v: number);
    /**
     * Gets or sets the value that maps to the maximum heat color.
    */
    get heatMaximum(): number;
    set heatMaximum(v: number);
    /**
     * Gets or sets the color to use for the minimum end of the scale.
    */
    get heatMinimumColor(): string;
    set heatMinimumColor(v: string);
    /**
     * Gets or sets the color to use for the maximum end of the scale.
    */
    get heatMaximumColor(): string;
    set heatMaximumColor(v: string);
    /**
     * Gets or sets the the pixel extent of the square data points that are rendered.
    */
    get pointExtent(): number;
    set pointExtent(v: number);
    /**
     * Represents the current status of the progressive load of the series. It will range from 0 to 100, where 100 is fully loaded.
    */
    get progressiveStatus(): number;
    set progressiveStatus(v: number);
    bindAxes(axes: IgrAxis[]): void;
    findByName(name: string): any;
    protected _styling(container: any, component: any, parent?: any): void;
    getItemValue(item: any, memberPathName: string): any;
    /**
     * Determine if object can be used as YAxis
    
    * @param axis  * The object to check
    */
    canUseAsYAxis(axis: any): boolean;
    /**
     * Determine if object can be used as XAxis
    
    * @param axis  * The object to check
    */
    canUseAsXAxis(axis: any): boolean;
    /**
     * Scrolls the series to display the item for the specified data item.
     * The series is scrolled by the minimum amount required to place the specified data item within
     * the central 80% of the visible axis.
    
    * @param item  * The data item (item) to scroll to.
    */
    scrollIntoView(item: any): boolean;
    /**
     * Gets the item that is the best match for the specified world coordinates.
    
    * @param world  * The world coordinates to use.
    */
    getItem(world: IgPoint): any;
    private _progressiveLoadStatusChanged;
    private _progressiveLoadStatusChanged_wrapped;
    /**
     * Raised when the progressive loading state of the series has changed.
    */
    get progressiveLoadStatusChanged(): (s: IgrHighDensityScatterSeries, e: IgrProgressiveLoadStatusEventArgs) => void;
    set progressiveLoadStatusChanged(ev: (s: IgrHighDensityScatterSeries, e: IgrProgressiveLoadStatusEventArgs) => void);
}
export interface IIgrHighDensityScatterSeriesProps extends IIgrSeriesProps {
    /**
     * Gets or sets the effective x-axis for the current object.
    */
    xAxis?: IgrNumericXAxis;
    /**
    * Gets or sets the name to use to resolve xAxis from markup.
    */
    xAxisName?: string;
    /**
     * Gets or sets the effective y-axis for the current object.
    */
    yAxis?: IgrNumericYAxis;
    /**
    * Gets or sets the name to use to resolve yAxis from markup.
    */
    yAxisName?: string;
    /**
     * Gets or sets the x value mapping property for the current series object.
    */
    xMemberPath?: string;
    /**
     * Gets or sets the label displayed before series X value in the Data Legend.
    */
    xMemberAsLegendLabel?: string;
    /**
     * Gets or sets the label displayed before series Y value in the Data Legend.
    */
    yMemberAsLegendLabel?: string;
    /**
     * Gets or sets the unit after displayed after series X value in the Data Legend.
    */
    xMemberAsLegendUnit?: string;
    /**
     * Gets or sets the unit after displayed after series Y value in the Data Legend.
    */
    yMemberAsLegendUnit?: string;
    /**
     * Gets or sets the y value mapping property for the current series object.
    */
    yMemberPath?: string;
    /**
     * Gets or sets the whether to use use brute force mode.
    */
    useBruteForce?: boolean | string;
    /**
     * Gets or sets the whether to progressively load the data into the chart.
    */
    progressiveLoad?: boolean | string;
    /**
     * Gets or sets the density value that maps to the minimum heat color.
    */
    heatMinimum?: number | string;
    /**
     * Gets or sets the value that maps to the maximum heat color.
    */
    heatMaximum?: number | string;
    /**
     * Gets or sets the color to use for the minimum end of the scale.
    */
    heatMinimumColor?: string;
    /**
     * Gets or sets the color to use for the maximum end of the scale.
    */
    heatMaximumColor?: string;
    /**
     * Gets or sets the the pixel extent of the square data points that are rendered.
    */
    pointExtent?: number | string;
    /**
     * Represents the current status of the progressive load of the series. It will range from 0 to 100, where 100 is fully loaded.
    */
    progressiveStatus?: number | string;
    /**
     * Raised when the progressive loading state of the series has changed.
    */
    progressiveLoadStatusChanged?: (s: IgrHighDensityScatterSeries, e: IgrProgressiveLoadStatusEventArgs) => void;
}
