import { IgrHorizontalAnchoredCategorySeries, IIgrHorizontalAnchoredCategorySeriesProps } from "./igr-horizontal-anchored-category-series";
import { PointSeries } from "./PointSeries";
/**
 * Represents a IgxDataChartComponent point series.
*
* You can use the `IgrPointSeries` plot a value along a category or date.
*
* ```ts
* <IgrDataChart
*     dataSource={this.state.dataSource}
*     width="700px"
*     height="500px">
*
*     <IgrCategoryXAxis name="xAxis" label="Date" />
*     <IgrNumericYAxis  name="yAxis" />
*    <IgrPointSeries
*     name="series1"
*     xAxisName="xAxis"
*     yAxisName="yAxis"
*     volumeMemberPath="Volume" />
*  </IgrDataChart>
* ```
*
* ```ts
* const series1 = new IgrPointSeries({ name: "series1" });
* series1.xAxisName = "xAxis";
* series1.yAxisName = "yAxis";
* series1.markerType = MarkerType.Circle;
* series1.valueMemberPath = "USA";
* ```
*/
export declare class IgrPointSeries extends IgrHorizontalAnchoredCategorySeries<IIgrPointSeriesProps> {
    protected createImplementation(): PointSeries;
    /**
                                 * @hidden
                                 */
    get i(): PointSeries;
    constructor(props: IIgrPointSeriesProps);
    /**
     * Gets whether the series has only marker as visuals
    */
    get hasOnlyMarkers(): boolean;
}
export interface IIgrPointSeriesProps extends IIgrHorizontalAnchoredCategorySeriesProps {
}
