import { IgrStrategyBasedIndicator, IIgrStrategyBasedIndicatorProps } from "./igr-strategy-based-indicator";
import { PositiveVolumeIndexIndicator } from "./PositiveVolumeIndexIndicator";
/**
 * Represents a IgxDataChartComponent Positive Volume Index (PVI) indicator series.
 * Default required members: Close, Volume
*
* You can use the `IgrPositiveVolumeIndexIndicator` with the 'NegativeVolumeIndexIndicator' to identify bull markets.
*
* ```ts
* <IgrDataChart
*     dataSource={this.state.dataSource}
*     width="700px"
*     height="500px">
*
*     <IgrCategoryXAxis name="xAxis" label="Date" />
*     <IgrNumericYAxis  name="yAxis" />
*    <IgrPositiveVolumeIndexIndicator
*      name="series1"
*     lowMemberPath="Low"
*     highMemberPath="High"
*     openMemberPath="Open"
*     closeMemberPath="Close"
*     volumeMemberPath="Volume" />
*  </IgrDataChart>
* ```
*
* ```ts
* let series = new IgrPositiveVolumeIndexIndicator ({name:"series1"});
* series.xAxisName = this.xAxis;
* series.yAxisName = this.yAxis;
* series.xAxis = this.categoryXAxis;
* series.yAxis = this.numericYAxis;
* series.openMemberPath = "open";
* series.highMemberPath = "high";
* series.lowMemberPath = "low";
* series.closeMemberPath = "close";
* ```
*/
export declare class IgrPositiveVolumeIndexIndicator extends IgrStrategyBasedIndicator<IIgrPositiveVolumeIndexIndicatorProps> {
    protected createImplementation(): PositiveVolumeIndexIndicator;
    /**
                                 * @hidden
                                 */
    get i(): PositiveVolumeIndexIndicator;
    constructor(props: IIgrPositiveVolumeIndexIndicatorProps);
}
export interface IIgrPositiveVolumeIndexIndicatorProps extends IIgrStrategyBasedIndicatorProps {
}
