import { SplineType } from "./SplineType";
import { IgrHorizontalAnchoredCategorySeries, IIgrHorizontalAnchoredCategorySeriesProps } from "./igr-horizontal-anchored-category-series";
import { SplineSeriesBase } from "./SplineSeriesBase";
/**
 * Represents the base class for all IgxDataChartComponent spline series.
*/
export declare abstract class IgrSplineSeriesBase<P extends IIgrSplineSeriesBaseProps = IIgrSplineSeriesBaseProps> extends IgrHorizontalAnchoredCategorySeries<P> {
    /**
                                 * @hidden
                                 */
    get i(): SplineSeriesBase;
    constructor(props: P);
    /**
     * Gets or sets whether to include the spline shape in the axis range requested of the axis.
    */
    get isSplineShapePartOfRange(): boolean;
    set isSplineShapePartOfRange(v: boolean);
    /**
     * Gets whether the current series shows an area or line shape.
    */
    get isAreaOrLine(): boolean;
    /**
     * Gets or sets the type of spline to be rendered.
    *
    * ```ts
    * this.series.splineType = SplineType.Clamped;
    * ```
    *
    * ```ts
    *  <IgrDataChart
    *     dataSource={this.state.dataSource} >
    *
    *     <IgrCategoryXAxis name="xAxis" />
    *     <IgrNumericYAxis name="yAxis" />
    *
    *     <IgrSplineAreaSeries
    *      name="series1"
    *      valueMemberPath="value"/>
    *  </IgrDataChart>
    * ```
    */
    get splineType(): SplineType;
    set splineType(v: SplineType);
}
export interface IIgrSplineSeriesBaseProps extends IIgrHorizontalAnchoredCategorySeriesProps {
    /**
     * Gets or sets whether to include the spline shape in the axis range requested of the axis.
    */
    isSplineShapePartOfRange?: boolean | string;
    /**
     * Gets or sets the type of spline to be rendered.
    *
    * ```ts
    * this.series.splineType = SplineType.Clamped;
    * ```
    *
    * ```ts
    *  <IgrDataChart
    *     dataSource={this.state.dataSource} >
    *
    *     <IgrCategoryXAxis name="xAxis" />
    *     <IgrNumericYAxis name="yAxis" />
    *
    *     <IgrSplineAreaSeries
    *      name="series1"
    *      valueMemberPath="value"/>
    *  </IgrDataChart>
    * ```
    */
    splineType?: SplineType | string;
}
