import { IgrHorizontalAnchoredCategorySeries, IIgrHorizontalAnchoredCategorySeriesProps } from "./igr-horizontal-anchored-category-series";
import { StepLineSeries } from "./StepLineSeries";
/**
 * Represents a IgxDataChartComponent step line series.
*
* ```ts
* <IgrDataChart
*     dataSource={this.state.dataSource}
*     width="700px"
*     height="500px">
*
*     <IgrCategoryXAxis name="xAxis" label="Year" />
*     <IgrNumericYAxis  name="yAxis" />
*
*     <IgrStepLineSeries
*         name="series1"
*         xAxisName="xAxis"
*         yAxisName="yAxis"
* 		valueMemberPath="value" />
*  </IgrDataChart>
* ```
*
* ```ts
*   let series = new IgrStepLineSeries({name:"series1"});
*   series.xAxis = this.xAxis;
*   series.yAxis = this.yAxis;
*   series.valueMemberPath="value";
*   this.chart.series.add(series);
* ```
*/
export declare class IgrStepLineSeries extends IgrHorizontalAnchoredCategorySeries<IIgrStepLineSeriesProps> {
    protected createImplementation(): StepLineSeries;
    /**
                                 * @hidden
                                 */
    get i(): StepLineSeries;
    constructor(props: IIgrStepLineSeriesProps);
    /**
     * Gets whether the current series shows only line shapes.
    */
    get isLineOnly(): boolean;
    /**
     * Gets whether the current series shows step shapes.
    */
    get isStep(): boolean;
    /**
     * Overridden by derived series classes to indicate when marker-less display is preferred or not.
    */
    get isMarkerlessDisplayPreferred(): boolean;
    /**
     * Gets whether the current series shows an area or line shape.
    */
    get isAreaOrLine(): boolean;
}
export interface IIgrStepLineSeriesProps extends IIgrHorizontalAnchoredCategorySeriesProps {
}
